@@ -39,9 +39,10 @@ class Settings(TypedDict, total=False):
     version_provider: str | None
     version_scheme: str | None
     version_type: str | None
-    tag_format: str | None
+    tag_format: str
     bump_message: str | None
     allow_abort: bool
+    allowed_prefixes: list[str]
     changelog_file: str
     changelog_incremental: bool
     changelog_start_rev: str | None
@@ -72,9 +73,16 @@ DEFAULT_SETTINGS: Settings = {
     "version_files": [],
     "version_provider": "commitizen",
     "version_scheme": None,
-    "tag_format": None,  # example v$version
+    "tag_format": "$version",  # example v$version
     "bump_message": None,  # bumped v$current_version to $new_version
     "allow_abort": False,
+    "allowed_prefixes": [
+        "Merge",
+        "Revert",
+        "Pull request",
+        "fixup!",
+        "squash!",
+    ],
     "changelog_file": "CHANGELOG.md",
     "changelog_incremental": False,
     "changelog_start_rev": None,
